@@ -75,7 +75,7 @@ sub PDL_BOOT {
 #ifndef aTHX_
 #define aTHX_
 #endif
-   if (SvTRUE (ERRSV)) Perl_croak(aTHX_ SvPV_nolen (ERRSV));
+   if (SvTRUE (ERRSV)) Perl_croak(aTHX_ "%s",SvPV_nolen (ERRSV));
    CoreSV = perl_get_sv("PDL::SHARE",FALSE);  /* SV* value */
    if (CoreSV==NULL)
      Perl_croak(aTHX_ "We require the PDL::Core module, which was not found");
@@ -270,7 +270,7 @@ sub genpp {
 
       s/O_NONBLOCK/$O_NONBLOCK/go;   # I/O
 
-      if ( /(\s*)?\bGENERICLOOP\s*\(([^\)]*)\)(\s*;)?/ ){  # Start of generic code
+      if ( m/ (\s*)? \b GENERICLOOP \s* \( ( [^\)]* ) \) ( \s*; )? /x ){  # Start of generic code
          #print $MATCH, "=$1=\n";
 
          die "Found GENERICLOOP while searching for ENDGENERICLOOP\n" if $gotstart;
@@ -284,7 +284,7 @@ sub genpp {
          next;
       }
 
-      if ( /\bENDGENERICLOOP(\s*;)?/ ) {
+      if ( m/ \b ENDGENERICLOOP ( \s*; )? /x ) {
 
          die "Found ENDGENERICLOOP while searching for GENERICLOOP\n" unless $gotstart;
 
@@ -364,25 +364,40 @@ EOF
 }
 
 # Expects list in format:
-# [gtest.pd, GTest, PDL::GTest], [...]
-# source,    prefix,module/package
-# The idea is to support in future several packages in same dir.
+# [gtest.pd, GTest, PDL::GTest,     ['../GIS/Proj', ...] ], [...]
+# source,    prefix,module/package, optional deps
+# The idea is to support in future several packages in same dir - EUMM
+#   7.06 supports
+# each optional dep is a relative dir that a "make" will chdir to and
+# "make" first - so the *.pd file can then "use" what it makes
 
 # This is the function internal for PDL.
-# Later on, we shall provide another for use outside PDL.
-#
+
 sub pdlpp_postamble_int {
-	join '',map { my($src,$pref,$mod) = @$_;
+	join '',map { my($src,$pref,$mod, $deps) = @$_;
+        die "If give dependencies, must be array-ref" if $deps and !ref $deps;
 	my $w = whereami_any();
 	$w =~ s%/((PDL)|(Basic))$%%;  # remove the trailing subdir
-	my $basic = File::Spec->abs2rel(File::Spec->catdir($w, 'Basic'));
+	my $top = File::Spec->abs2rel($w);
+	my $basic = File::Spec->catdir($top, 'Basic');
 	my $core = File::Spec->catdir($basic, 'Core');
 	my $gen = File::Spec->catdir($basic, 'Gen');
-
+        my $depbuild = '';
+        for my $dep (@{$deps || []}) {
+            my $target = '';
+            if ($dep eq 'core') {
+                $dep = $top;
+                $target = ' core';
+            }
+            require ExtUtils::MM;
+            $dep =~ s#([\(\)])#\\$1#g; # in case of unbalanced (
+            $depbuild .= MM->oneliner("exit(!(chdir q($dep) && !system(q(\$(MAKE)$target))))");
+            $depbuild .= "\n\t";
+        }
 qq|
 
 $pref.pm: $src $core/Types.pm
-	\$(PERLRUNINST) \"-MPDL::PP qw/$mod $mod $pref/\" $src
+	$depbuild\$(PERLRUNINST) \"-MPDL::PP qw/$mod $mod $pref/\" $src
 
 $pref.xs: $pref.pm
 	\$(TOUCH) \$@
